# Generated by Django 3.2.4 on 2021-09-28 13:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_old_records', '0001_initial_squashed_0006_alter_modelconfig_max_age'),
    ]

    operations = [
        migrations.AddField(
            model_name='modelconfig',
            name='created_at_field',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
    ]
